<?php
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

if ( ! class_exists( 'Woo_Cl_Settings_Tabs' ) ) :

/**
 * Setting page Class
 * 
 * Handles Settings page functionality of plugin
 * 
 * @package WPWeb WooCommerce Collections
 * @since 1.1.5
 */
class Woo_Cl_Settings_Tabs extends WC_Settings_Page {

	/**
	 * Constructor
	 * 
	 * Handles to add hooks for adding settings
	 * 
	 * @package WPWeb WooCommerce Collections
	 * @since 1.1.5
	 */
	public function __construct() {

		global $woo_cl_model; // Declare global variables

		$this->id    	= 'woo-cl-settings'; // Get id
		$this->label 	= woo_cl_get_label_plural();// Get tab label
		$this->model 	= $woo_cl_model; // Declare variable $this->model

		$this->email_address     = get_option( 'woo_cl_email_address' );
		$this->activation_code   = get_option( 'woo_cl_activation_code' );
		$this->activation_status = woo_cl_is_license_activated();

		// Add filter for adding tab
		add_filter( 'woocommerce_settings_tabs_array', array( $this, 'add_settings_page' ), 20 );

		// Add action to show output
		add_action( 'woocommerce_settings_' . $this->id, array( $this, 'woo_cl_output' ) );

		// Add action for saving data
		add_action( 'woocommerce_settings_save_' . $this->id, array( $this, 'woo_cl_save' ) );

		// Add action for adding sections
		add_action( 'woocommerce_sections_' . $this->id, array( $this, 'output_sections' ) );

		// Add a custom field types
		add_action( 'woocommerce_admin_field_woo_cl_textarea', array( $this, 'woo_cl_admin_field_woo_cl_textarea' ) );
		add_action( 'woocommerce_admin_field_woo_cl_multiselect', array( $this, 'woo_cl_admin_field_woo_cl_multiselect' ) );
		add_action( 'woocommerce_admin_field_woo_cl_button_preview', array( $this, 'woo_cl_admin_field_woo_cl_button_preview' ) );

		add_action( 'woocommerce_admin_field_woo_cl_license_button', array( $this, 'woo_cl_license_button_callback' ) );
		add_action( 'woocommerce_admin_field_woo_cl_license_description', array( $this, 'woo_cl_license_description_callback' ) );
	}

	/**
	 * Add woo_cl_textarea type Setting
	 * 
	 * Handles to add woo_cl_textarea field
	 * type for admin side
	 * 
	 * @package WPWeb WooCommerce Collections
 	 * @since 1.1.5
	 */
	public function woo_cl_admin_field_woo_cl_textarea( $field ) {

		global $woocommerce;

		if ( isset( $field['title'] ) && isset( $field['id'] ) ) :

			$file_val		= get_option( $field['id'] );
			$file_val		= !empty($file_val) ? $file_val : '';
			$editor			= ( isset( $field['editor'] ) && $field['editor'] == true ) ? true : false;
			$editor_cofig	= array(
									'media_buttons'	=> true,
									'textarea_rows'	=> 5,
									'editor_class'	=> 'woo-cl-wpeditor'
								); ?>
				
				<tr valign="top">
					<th scope="row" class="titledesc">
						<label for="<?php echo esc_attr( $field['id'] ); ?>"><?php echo wp_kses_post( $field['title'] ); ?></label>
					</th>
					<td class="forminp forminp-text">
						<fieldset><?php 
							if( $editor ) {
								
								wp_editor( $file_val, esc_attr( $field['id'] ), $editor_cofig );
								
							} else { ?>
								
								<textarea name="<?php echo esc_attr( $field['id']  ); ?>" id="<?php echo esc_attr( $field['id'] ); ?>" style="<?php echo esc_attr( $field['css'] ); ?>;"/><?php echo esc_attr( $file_val ); ?></textarea><?php 
							} ?>
						</fieldset>
						<span class="description"><?php echo $field['desc'];?></span>
					</td>
				</tr><?php
		endif;
	}

	/**
	 * Add woo_cl_multiselect type Setting
	 * 
	 * Handles to add woo_cl_multiselect field
	 * type for admin side
	 * 
	 * @package WPWeb WooCommerce Collections
 	 * @since 1.1.5
	 */
	public function woo_cl_admin_field_woo_cl_multiselect ( $field ) {

		if ( isset( $field['title'] ) && isset( $field['id'] ) && ! empty( $field['val'] ) ) {

			$available_fields = $field['val'];
			
			wp_enqueue_script('jquery');
			
			$file_val		= get_option( $field['id'] );
			
			echo '<tr valign="top">';
			echo '<th scope="row" class="titledesc">';
			echo '<label for="' . esc_attr( $field['id'] ) . '">' . wp_kses_post( $field['title'] ) . '</label>';
			echo '</th><td class="forminp forminp-multiselect woo-cl-disable-add-collection-btn"><fieldset>';
			echo '<select multiple name="' . esc_attr( $field['id']  ) . '[]" id="' . esc_attr( $field['id']  ) . '" class="'. esc_attr( $field['class']  ) . '">';
			foreach ( $available_fields as $available_field_key => $available_field_val ) {
				$option = '';
				$option .= '<option value="' . $available_field_key . '"';
				if ( !empty( $file_val ) && in_array( $available_field_key, $file_val ) ) {
					$option .= ' selected = "selected"';
				}
				$option .= ' >' . $available_field_val . '</option>';
				echo $option;
			}
			echo '</select></label></fieldset>';
			echo '<span class="description">' . $field['desc'] . '</span></td>';
		}
	}

	/**
	 * Add woo_cl_button_preview type to Display add to collection button preview
	 * 
	 * Handles to add button_preview field
	 * type for admin side
	 * 
	 * @package WPWeb WooCommerce Collections
 	 * @since 1.1.5
	 */
	public function woo_cl_admin_field_woo_cl_button_preview( $field ) {

		if ( isset( $field['title'] ) && isset( $field['id'] ) ) : ?>
			<tr valign="top">
				<th scope="row" class="titledesc">
					<label for="<?php echo esc_attr( $field['id'] ); ?>"><?php echo wp_kses_post( $field['title'] ); ?></label>
				</th>
				<td id="<?php echo esc_attr( $field['id'] ); ?>" class="forminp forminp-text">
					<?php
					// Get button class based on option
					$button_type = get_option( 'cl_add_to_collection_btn_type' );
					if( $button_type == 'default' ) {
						$button_class = 'alt button';
					} else if( $button_type == 'button' ) {
						$button_class = 'woocl-button';
					}

					//create add to collection button
					do_action( 'woo_cl_add_to_collection_button', array(
						'variation_class'		=> '',
						'button_class'			=> !empty( $button_class ) ? $button_class : '',
						'add_to_coll_btn'		=> str_replace( '{no_of_collections}', 0, get_option( 'cl_add_to_collection_btn_text' ) ),
						'add_to_coll_btnicon'	=> get_option( 'cl_add_to_collection_link_icon' ),
						'icon_position'			=> 'left',
					));?>
				</td>
			</tr><?php
		endif;
	}


	/**
	 * License button Callback
	 * 
	 * Handles to License button Callback
	 * type for admin side
	 * 
	 * @package WPWeb WooCommerce Collections
 	 * @since 1.1.5
	 */
	public function woo_cl_license_button_callback( $field ) {

		global $woocommerce;

		if ( isset( $field['title'] ) && isset( $field['id'] ) ) {
			$filetype	= isset( $field['options'] ) ? $field['options'] : '';
			$file_val	= get_option( $field['id'] );
			$file_val	= !empty($file_val) ? $file_val : '';
			
			?>
			<tr valign="top">
				<th scope="row" class="woo-cl-license-button">
					<button id="check-license" class="button check-license-cl"><?php esc_html_e($field['btn_title']); ?></button>	
					<span id="loader">
						<img src="<?php echo esc_url( WOO_CL_IMG_URL ) . '/woo-cl-loader.gif'; ?>" alt="Loading...">
					</span>
				</th>
			</tr>
			<?php
		}

	}


	/**
	 * Add woo_cl_license_description to Display license activation detail
	 * 
	 * Handles to add license_description field
	 * type for admin side
	 * 
	 * @package WPWeb WooCommerce Collections
 	 * @since 1.1.5
	 */
	public function woo_cl_license_description_callback( $field ) {

		global $woocommerce;

		if ( isset( $field['title'] ) && isset( $field['id'] ) ) {
			$filetype	= isset( $field['options'] ) ? $field['options'] : '';
			$file_val	= get_option( $field['id'] );
			$file_val	= !empty($file_val) ? $file_val : '';
			
			?>
			<tr valign="top">
				<td colspan="2">
					<div class="wpweb-db-reg-howto">
					<h3 class="wpweb-db-reg-howto-heading"><?php esc_html_e( 'How To Find Your Purchase Code', 'woocl' ); ?></h3>
					<ol class="wpweb-db-reg-howto-list wpweb-db-card-text-small">
						<li>
							<?php
							printf(
								/* translators: "CodeCanyon sign in link" link. */
								__( 'Sign in to your %s. <strong>IMPORTANT:</strong> You must be signed into the same CodeCanyon account that purchased WooCommerce Collections. If you are signed in already, look in the top menu bar to ensure it is the right account.', 'woocl' ), // phpcs:ignore WordPress.Security.EscapeOutput
								'<a href="https://codecanyon.net/sign_in" target="_blank">' . esc_html__( 'CodeCanyon account', 'woocl' ) . '</a>'
							);
							?>
						</li>
						<li>
							<?php
							printf(
								/* translators: "Generate A Personal Token" link. */
								__( 'Visit the %s. You should see a row for WooCommerce Collections.  If you don\'t, please re-check step 1 that you are on the correct account.', 'woocl' ), // phpcs:ignore WordPress.Security.EscapeOutput
								'<a href="https://codecanyon.net/downloads" target="_blank">' . esc_html__( 'CodeCanyon downloads page', 'woocl' ) . '</a>'
							);
							?>
						</li>
						<li>
							<?php
								esc_html_e( 'Click the download button in the WooCommerce Collections row.', 'woocl' )
							?>
						</li>
						<li>
							<?php
								esc_html_e( 'Select either License certificate & purchase code (PDF) or License certificate & purchase code (text). This should then download either a text or PDF file.', 'woocl' )
							?>
						</li>
						<li>
							<?php
								esc_html_e( 'Open up that newly downloaded file and copy the Item Purchase Code.', 'woocl' )
							?>
						</li>
					</ol>
				</div>
				</td>
			</tr>
			<?php
		}

	}


	/**
	 * Handles to add sections for Settings tab
	 * 
	 * @package WPWeb WooCommerce Collections
	 * @since 1.1.5
	 */
	public function get_sections() {

		if($this->activation_status){
			// Create array
			$sections = array(
				''          				=> esc_html__( 'General Settings', 'woocl' ),
				'cl_display_settings'  		=> esc_html__( 'Display Settings', 'woocl' ),
				'cl_misc_settings'  		=> esc_html__( 'Misc Settings', 'woocl' ),
			);
		}else{
			// Create array
			$sections = array();
		}	

		$sections['cl_license'] = esc_html__( 'License', 'woocl' );

		return apply_filters( 'woo_cl_setting_sections', $sections );
	}

	/**
	 * Handles to output data
	 * 
	 * @package WPWeb WooCommerce Collections
	 * @since 1.1.5
	 */
	public function woo_cl_output() {

		// Get global variable
		global $current_section;

		if(!$this->activation_status){
			$current_section = 'cl_license';
		}

		// Get settings for current section
		$settings = $this->get_settings( $current_section );

		WC_Admin_Settings::output_fields( $settings );
	}

	/**
	 * Handles to save data
	 * 
	 * @package WPWeb WooCommerce Collections
	 * @since 1.1.5
	 */
	public function woo_cl_save() {

		global $current_section;
		
		if( empty( $_POST['cl_add_to_collection_btn_text'] ) ) {//default value set to add to collection button
			$_POST['cl_add_to_collection_btn_text'] = esc_html__( 'Add to Collections', 'woocl' );
		}
		
		if( isset( $_POST['cl_pagination_options'] ) ) {//set integer value in per page field
			
			//typecast per page to integer value
			$cl_pagination_options	= intval( $_POST['cl_pagination_options'] );
			
			if( empty( $cl_pagination_options ) ) {//if per page is empty then set default per page
				$_POST['cl_pagination_options'] = WOO_CL_POST_PER_PAGE;
			}
		}
		
		if( isset( $_POST['cl_no_of_col_items_list'] ) ) {//set integer value in column per page field
			
			//typecast per page to integer value
			$cl_pagination_options	= intval( $_POST['cl_no_of_col_items_list'] );
			
			if( empty( $cl_pagination_options ) ) {//if per page is empty then set default per page
				$_POST['cl_no_of_col_items_list'] = WOO_CL_NUM_COL_COLL_LIST;
			}
		}

		if( isset( $_POST['cl_no_of_my_collection_items'] ) ) {//set integer value in no of my collections field
			
			//typecast per page to integer value
			$cl_no_of_my_collections_items = intval( $_POST['cl_no_of_my_collection_items'] );
			
			if( empty( $cl_no_of_my_collections_items ) ) {//if per page is empty then set default per page
				$_POST['cl_no_of_my_collection_items'] = WOO_CL_NO_OF_MY_COLLECTION_ITEMS;
			}
		}

		if( isset( $_POST['cl_max_collections_per_user'] ) ) {//set integer value in max collection per user field

			//typecast per page to integer value
			$cl_max_collections_per_user = intval( $_POST['cl_max_collections_per_user'] );

			if( empty( $cl_max_collections_per_user ) ) {//if per page is empty then set default max collections
				$_POST['cl_max_collections_per_user'] = '';
			}
		}

		if( isset( $_POST['cl_max_products_per_collection'] ) ) {//set integer value in max products per collection field

			//typecast per page to integer value
			$cl_max_products_per_collection = intval( $_POST['cl_max_products_per_collection'] );

			if( empty( $cl_max_products_per_collection ) ) {//if per page is empty then set default max products
				$_POST['cl_max_products_per_collection'] = '';
			}
		}

		if( isset( $_POST['cl_view_collection_text'] ) ) {//set default to view collections endpoints
			
			$cl_view_options	= trim( $_POST['cl_view_collection_text'] );
			
			if( empty( $cl_view_options ) ) {
				$_POST['cl_view_collection_text'] = WOO_CL_DEFAULT_VIEW;
			}
		}
		
		if( isset( $_POST['cl_edit_collection_text'] ) ) {//set default to edit collections endpoints
			
			$cl_edit_options	= trim( $_POST['cl_edit_collection_text'] );
			
			if( empty( $cl_edit_options ) ) {
				$_POST['cl_edit_collection_text'] = WOO_CL_DEFAULT_EDIT;
			}
		}
		
		if( isset( $_POST['cl_collection_author_text'] ) ) {//set default to author collections endpoints
			
			$cl_author_options	= trim( $_POST['cl_collection_author_text'] );
			
			if( empty( $cl_author_options ) ) {
				$_POST['cl_collection_author_text'] = WOO_CL_DEFAULT_AUTHOR;
			}
		}
		
		if ( !isset( $_POST['cl_disable_user_role'] ) ) {
			$_POST['cl_disable_user_role'] = '';
		}

		$settings = $this->get_settings( $current_section );				
		WC_Admin_Settings::save_fields( $settings );
	}

	/**
	 * Handles to get setting
	 * 
	 * @package WPWeb WooCommerce Collections
	 * @since 1.1.5
	 */
	public function get_settings( $current_section = '' ) {
		
		//Get Pagination options
		$cl_pagination_options	= get_option('cl_pagination_options');
		$cl_pagination_options	= ( trim( $cl_pagination_options ) != '' && is_numeric( $cl_pagination_options ) ) ? $cl_pagination_options : WOO_CL_POST_PER_PAGE;

		$icons	= array(
			'' 				=> esc_html__( 'None', 'woocl' ),
			'fa fa-star' 	=> esc_html__( 'Star', 'woocl' ),
			'fa fa-gift' 	=> esc_html__( 'Present', 'woocl' ),
			'fa fa-plus' 	=> esc_html__( 'Add', 'woocl' ),
			'fa fa-bookmark'=> esc_html__( 'Bookmark', 'woocl' ),
			'fa fa-heart' 	=> esc_html__( 'Heart', 'woocl' )
		);
		
		// Declare Sortable options array
		$sort_optns = array(
			'menu_order title-asc'	=> esc_html__( 'Custom Ordering + Title ( ASC )', 'woocl' ),
			'menu_order title-desc'	=> esc_html__( 'Custom Ordering + Title ( DESC )', 'woocl' ),
			'date-asc'		=> esc_html__( 'Date ( ASC )', 'woocl' ),
			'date-desc'		=> esc_html__( 'Date ( DESC )', 'woocl' ),
			'title-asc'		=> esc_html__( 'Title ( ASC )', 'woocl' ),
			'title-desc'	=> esc_html__( 'Title ( DESC )', 'woocl' ),
		);
		
		//Get columns details
		$columns 		= array();
		$max_columns	= woo_cl_get_max_listing_columns();
		if( $max_columns > 2 ) {
			for( $itr = 2; $itr <= $max_columns; $itr++ ) {
				$columns[$itr]	= sprintf( esc_html__( '%s columns', 'woocl' ), $itr );
			}
		}

		// Load user.php before use get_editable_roles function
		if ( ! function_exists( 'get_editable_roles' ) ) {
		    require_once ABSPATH . 'wp-admin/includes/user.php';
		}

		// Get User roles
		$user_roles		= get_editable_roles();

		$user_editable_role = array();
		foreach( $user_roles as $user_role_key => $user_role_val ) {
			$user_editable_role[$user_role_key] = $user_role_val['name'];
		}
		
		// If collection settings are selected
		if ( 'cl_display_settings' == $current_section ) {

			$settings = array(
			
				array( 
					'name'	=>	sprintf( esc_html__( 'Display Settings', 'woocl' ), woo_cl_get_label_singular() ),
					'type'	=>	'title',
					'desc'	=>	'',
					'id'	=>	'cl_display_settings'
				),
				array(
					'id'		=> 'cl_pagination_options',
					'name'		=> esc_html__( 'Items Per Page', 'woocl' ),
					'desc'		=> sprintf( esc_html__( '%sEnter number of "%s / %s" items you want to display per page. Leave it empty for unlimited.%s', 'woocl' ), '<p class="description">', woo_cl_get_label_plural(), woo_cl_get_label_singular(), '</p>' ),
					'type'		=> 'text',
					'class'		=> 'small-text',
					'desc_tip'	=> ''
				),
				array(
					'id'		=> 'cl_no_of_col_items_list',
					'name'		=> esc_html__( 'Grid Column', 'woocl' ),
					'desc'		=> sprintf( esc_html__( '%sSelect number of columns for "%s listing / %s items" page.%s', 'woocl' ), '<p class="description">', woo_cl_get_label_plural(), woo_cl_get_label_singular(), '</p>' ),
					'type'		=> 'select',
					'class'		=> 'small-text',
					'desc_tip'	=> '',
					'default' 	=> '3',
					'options' 	=> $columns,
                    'css'       => 'padding: 0px 6px;'
				),
				array(
					'id'		=> 'cl_no_of_my_collection_items',
					'name'		=> sprintf( esc_html__( 'Number of My %s', 'woocl' ), woo_cl_get_label_plural() ),
					'desc'		=> sprintf( esc_html__( '%sEnter number of %s you want to display on %s"My Account page"%s. Leave it empty for unlimited.%s', 'woocl' ), '<p class="description">', woo_cl_get_label_plural(true),'<strong>','</strong>', '</p>' ),
					'type'		=> 'text',
					'class'		=> 'small-text',
					'desc_tip'	=> ''
				),
				array(
					'id'		=> 'cl_collection_subtitle_text',
					'name'		=> sprintf( esc_html__( '%s Sub Title Text', 'woocl' ), woo_cl_get_label_singular() ),
					'desc'		=> sprintf( esc_html__( '%2$sEnter the %1$s sub title which you want to display on view %1$s page below the %1$s title. Available template tag are :', 'woocl' ), woo_cl_get_label_singular(true), '<p class="description">' )
						.'<br /><code>{total_price}</code> - '.sprintf( esc_html__( 'display the total price', 'woocl' ) )
						.'<br /><code>{total_items}</code> - '.sprintf( esc_html__( 'display the no of items', 'woocl' ) ).'</p>',
					'type'		=> 'text',
					'class'		=> 'small-text',
					'desc_tip'	=> ''
				),
				
				array(
					'id'		=> 'cl_enable_editor_coll_desc',
					'name'		=> sprintf( esc_html__( 'Enable Editor On %s', 'woocl' ), woo_cl_get_label_plural() ),
					'desc'		=> '',
					'type'		=> 'checkbox',
					'desc_tip'	=> sprintf( esc_html__( 'Check this box if you want to enable tinyMCE editor for adding description field on edit %s page.','woocl' ), woo_cl_get_label_singular() )
				),
				array(
					'id'		=> 'cl_enable_front_drag_item_ordering',
					'name'		=> esc_html__( 'Enable Item Drag & Drop Ordering', 'woocl' ),
					'desc'		=> '',
					'type'		=> 'checkbox',
					'desc_tip'	=> sprintf( esc_html__( 'Check this box if you want to add drag & drop feature on edit %1$s page to manage items ordering.','woocl' ), woo_cl_get_label_singular(true) )
				),
				array(
	                'name' 			=> sprintf( esc_html__( 'Display My %s On', 'woocl' ), woo_cl_get_label_plural() ),
	                'desc' 			=> sprintf( esc_html__( 'Check this box to display My %s on WooCommerce %s"My Account page"%s.', 'woocl' ), woo_cl_get_label_plural(),'<strong>','</strong>' ),
					'id' 			=> 'cl_enable_woo_myaccount_page',
	                'std' 			=> 'yes',
	                'default' 		=> 'yes',
	                'type' 			=> 'checkbox',
			            'checkboxgroup' => 'start'
		        ),
		        array(
	                'name' 			=> sprintf( esc_html__( 'Display Private %s', 'woocl' ), woo_cl_get_label_plural() ),
	                'desc' 			=> sprintf( esc_html__( 'Check this box if you want to display private %s on %s"My Account Page"%s.', 'woocl' ), woo_cl_get_label_plural(true),'<strong>','</strong>' ),
					'id' 			=> 'cl_enable_woo_private_myaccount_page',
	                'type' 			=> 'checkbox',
			        'checkboxgroup' => 'start',
		        ),
		    );

	        $settings = apply_filters( 'woo_cl_before_seaching_display_settings', $settings );

			$settings_2 = array(
				array(
					'type' 	=> 'sectionend',
					'id' 	=> 'cl_display_settings'
				),
				array( 
					'name'	=>	sprintf( esc_html__( 'Searching & Sorting Settings', 'woocl' ), woo_cl_get_label_singular() ),
					'type'	=>	'title',
					'desc'	=>	'',
					'id'	=>	'cl_search_and_sort_settings'
				),
				array(
					'id'		=> 'cl_enable_search_on_collections',
					'name'		=> sprintf( esc_html__( 'Enable %s Search', 'woocl' ), woo_cl_get_label_plural() ),
					'desc'		=> '',
					'type'		=> 'checkbox',
					'desc_tip'	=> sprintf( esc_html__( 'Check this box if you want to allow users to search %s on "%s listing page".','woocl' ), woo_cl_get_label_singular(true),woo_cl_get_label_singular(true) )
				),
				array(
					'id'		=> 'cl_enable_sorting_on_collections',
					'name'		=> sprintf( esc_html__( 'Enable %s Sorting', 'woocl' ), woo_cl_get_label_plural() ),
					'desc'		=> '',
					'type'		=> 'checkbox',
					'desc_tip'	=> sprintf( esc_html__( 'Check this box if you want to enable the sorting options on "%s listing page".','woocl' ), woo_cl_get_label_plural(true) )
				),
				array(
					'id'		=> 'cl_sort_collection_by',
					'name'		=> sprintf( esc_html__( 'Default %s Sorting', 'woocl' ), woo_cl_get_label_singular() ),
					'desc'		=> sprintf( esc_html__( '%sThis controls the default sort order of the %s.%s','woocl'), '<p class="description">', woo_cl_get_label_plural(true), '</p>' ),
					'type'		=> 'select',
					'class'		=> '',
				    'std' 		=> 'date-asc',
					'default' 	=> 'date-asc',
					'options' 	=> $sort_optns									
				),
				array(
					'id'		=> 'cl_enable_search_on_collection_items',
					'name'		=> sprintf( esc_html__( 'Enable %s item(s) Search', 'woocl' ), woo_cl_get_label_singular() ),
					'desc'		=> '',
					'type'		=> 'checkbox',
					'desc_tip'	=> sprintf( esc_html__( 'Check this box if you want to allow users to search %s items on %s item(s) listing page.','woocl' ), woo_cl_get_label_singular(), woo_cl_get_label_singular() )
				),
				array(
					'id'		=> 'cl_enable_sorting_on_collection_items',
					'name'		=> sprintf( esc_html__( 'Enable %s item(s) Sorting', 'woocl' ), woo_cl_get_label_singular() ),
					'desc'		=> '',
					'type'		=> 'checkbox',
					'desc_tip'	=> sprintf( esc_html__( 'Check this box if you want to enable sorting options on %s item(s) listing page.','woocl' ), woo_cl_get_label_singular() )
				),
				array(
					'id'		=> 'cl_sort_collection_item_by',
					'name'		=> sprintf( esc_html__( 'Default %s Items Sorting', 'woocl' ), woo_cl_get_label_singular() ),
					'desc'		=> sprintf( esc_html__( '%sThis controls the default sort order of the %s items.%s','woocl'), '<p class="description">', woo_cl_get_label_singular(true), '</p>' ),
					'type'		=> 'select',
					'class'		=> '',
				    'std' 		=> 'date-asc',
					'default' 	=> 'date-asc',
					'options' 	=> $sort_optns
				),
				array(
					'type' 	=> 'sectionend',
					'id' 	=> 'cl_search_and_sort_settings'
				),
				array( 
					'name'	=>	sprintf( esc_html__( 'Button Settings', 'woocl' ), woo_cl_get_label_singular() ),
					'type'	=>	'title',
					'desc'	=>	'',
					'id'	=>	'cl_collection_button_settings'
				),
				
				array(
					'id'		=> 'cl_add_to_collection_btn_text',
					'name'		=> esc_html__( 'Button / Link Text', 'woocl' ),
					'desc'		=> sprintf( esc_html__('%sAdd custom text for "Add to %s" button. Default is: Add to %s. Available template tag is :','woocl'), '<p class="description">', woo_cl_get_label_singular(), woo_cl_get_label_singular() ) .'<br /><code>{no_of_collections}</code> - '.sprintf( esc_html__( 'display the no of %s', 'woocl' ), woo_cl_get_label_plural() ).'</p>',
					'type'		=> 'text',
					'class'		=> '',
				    'std' 		=> esc_html__( 'Add to Collections', 'woocl' ),
					'default' 	=> esc_html__( 'Add to Collections', 'woocl' ),
				),
				array(
					'id'		=> 'cl_add_to_collection_btn_type',
					'name'		=> esc_html__( 'Button / Link Type', 'woocl' ),
					'desc'		=> sprintf( esc_html__('%sHere you can select a "add to %s" button/link type.','woocl'), '<p class="description">', woo_cl_get_label_singular(true), '</p>' ),
					'type'		=> 'select',
					'class'		=> '',
				    'std' 		=> 'button',
					'default' 	=> 'button',
					'options' 	=> array(  'default' => esc_html__( 'Default', 'woocl' ),  'button' => esc_html__( 'Button', 'woocl' ), 'link' => esc_html__( 'Link', 'woocl' ) )	
				),
				array(
					'id'		=> 'cl_add_to_collection_link_icon',
					'name'		=> esc_html__( 'Icon', 'woocl' ),
					'desc'		=> sprintf( esc_html__( '%sSelect an icon that you want to display next to the add to %s button/link.%s','woocl'), '<p class="description">', woo_cl_get_label_singular(true), '</p>' ),
					'type'		=> 'select',
					'class'		=> '',
				    'std' 		=> 'fa fa-gift',
					'default' 	=> 'fa fa-gift',
					'options' 	=> $icons									
				),
				array(
					'id'		=> 'cl_add_to_collection_btn_preview',
					'name'		=> esc_html__( 'Button Preview', 'woocl' ),
					'type'		=> 'woo_cl_button_preview',
					'class'		=> '',
				),
				array(
					'id'		=> 'cl_display_product_collections_text',
					'name'		=> sprintf( esc_html__( 'Display Text Before %s Button', 'woocl' ), woo_cl_get_label_singular() ),
					'desc'		=> sprintf( esc_html__( '%sEnter the text which you want to display before add to %s button. Available template tag is :', 'woocl' ), '<p class="description">', woo_cl_get_label_plural(true) )
						.'<br /><code>{collections}</code> - '.sprintf( esc_html__( 'displays the %s(s) title with comma separated.', 'woocl' ) ,  woo_cl_get_label_singular(true) ).'</p>',
					'type'		=> 'text',
					'class'		=> '',
					'desc_tip'	=> ''
				),
				array(
					'type' 	=> 'sectionend',
					'id' 	=> 'cl_collection_button_settings'
				),
				
				array( 
					'name'	=>	esc_html__( 'Style Settings', 'woocl' ),
					'type'	=>	'title',
					'desc'	=>	'',
					'id'	=>	'cl_style_settings'
				),
				array(
	                'name' 		=> esc_html__('Custom CSS', 'woocl'),
	                'class' 	=> '',
	                'css' 		=> 'width:100%;min-height:100px',
	                'desc' 		=> '<p class="description">'.esc_html__('Here you can enter your custom CSS for the Collections. The css will automatically added to the header, when you save it.', 'woocl').'</p>',
	                'id' 		=> 'cl_custom_css',
	                'type' 		=> 'woo_cl_textarea',
	                'default'	=> ''
	            ),
				
				// End Collection Option section
				array( 
					'type' 		=> 'sectionend',
					'id' 		=> 'cl_style_settings'
				),
				
			);

			//Merge all settings
	        $settings = apply_filters( 'woo_cl_display_settings', array_merge( $settings, $settings_2 ) );

		} elseif ( 'cl_misc_settings' == $current_section ) { // If misc settings is selected

			//Get Terminologies
			$terminologies = array(
				'' 				=> esc_html__( 'Collection', 'woocl' ),
				'lightbox' 		=> esc_html__( 'Light Box', 'woocl' ),
				'watchlist' 	=> esc_html__( 'Watch List', 'woocl' ),
				'wishlist' 		=> esc_html__( 'Wish List', 'woocl' ),
				'wantlist' 		=> esc_html__( 'Want List', 'woocl' ),
				'custom' 		=> esc_html__( 'Custom Text', 'woocl' )
			);

			$settings = apply_filters( 'cl_misc_settings', array(

				// Start Misc Settings section
				array( 
					'name'	=>	esc_html__( 'Misc Settings', 'woocl' ),
					'type'	=>	'title',
					'desc'	=>	'',
					'id'	=>	'cl_misc_settings'
				),
				array(
					'id'		=> 'cl_delete_options',
					'name'		=> esc_html__( 'Delete Options', 'woocl' ),
					'desc'		=> '',
					'type'		=> 'checkbox',
					'desc_tip'	=> sprintf( esc_html__( 'If you don\'t want to use the %s Plugin on your site anymore, you can check this setting. This makes sure, that all the settings and tables are being deleted from the database when you deactivate the plugin.','woocl' ), woo_cl_get_label_plural() )
				),
				array(
					'id'		=> 'cl_scroll_options',
					'name'		=> esc_html__( 'Enable Load More Button', 'woocl' ),
					'desc'		=> '',
					'type'		=> 'checkbox',
					'desc_tip'	=> sprintf( esc_html__( 'Check this box if you want to display "Load More" button after %s items per page.','woocl' ), $cl_pagination_options )
				),
				array( 
					'type' 		=> 'sectionend',
					'id' 		=> 'cl_misc_settings'
				),
				array( 
					'name'	=>	sprintf( esc_html__( '%s Terminology & Endpoints', 'woocl' ), woo_cl_get_label_plural() ),
					'type'	=>	'title',
					'desc'	=>	'',
					'id'	=>	'cl_endpoints_settings'
				),
				array(
					'id'		=> 'cl_collection_terminology',
					'name'		=> sprintf( esc_html__( '%s Terminology', 'woocl' ), woo_cl_get_label_singular() ),
					'desc'		=> sprintf( esc_html__('%sHere you can select the terminology which you want to show in place of text %s.%s','woocl'), '<p class="description">', woo_cl_get_label_singular(true), '</p>' ),
					'type'		=> 'select',
					'class'		=> '',
				    'std' 		=> '',
					'default' 	=> '',
					'options' 	=> $terminologies
				),
				array(
					'id'		=> 'cl_collection_terminology_singular_text',
					'name'		=> sprintf( esc_html__( 'Singular Text', 'woocl' ), woo_cl_get_label_singular() ),
					'desc'		=> '<p class="description">'.sprintf( esc_html__('Enter singular text for custom collection terminology.','woocl'), woo_cl_get_label_singular(true) ).'</p>',
					'type'		=> 'text',
					'class'		=> 'woocl-hidden-field',
				    'std' 		=> '',
					'default' 	=> '',
				),
				array(
					'id'		=> 'cl_collection_terminology_plural_text',
					'name'		=> sprintf( esc_html__( 'Plural Text', 'woocl' ), woo_cl_get_label_singular() ),
					'desc'		=> '<p class="description">'.sprintf( esc_html__('Enter plural text for custom collection terminology.','woocl'), woo_cl_get_label_singular(true) ).'</p>',
					'type'		=> 'text',
					'class'		=> 'woocl-hidden-field',
				    'std' 		=> '',
					'default' 	=> '',
				),
				array(
					'id'		=> 'cl_view_collection_text',
					'name'		=> sprintf( esc_html__( 'View %s', 'woocl' ), woo_cl_get_label_singular() ),
					'desc'		=> '<p class="description">'.sprintf( esc_html__('Endpoint for the %s -> View page, Default is: view-collection.','woocl'), woo_cl_get_label_singular() ).'</p>',
					'type'		=> 'text',
					'class'		=> '',
				    'std' 		=> 'view-collection',
					'default' 	=> 'view-collection',
				),
				array(
					'id'		=> 'cl_edit_collection_text',
					'name'		=> sprintf( esc_html__( 'Edit %s', 'woocl' ), woo_cl_get_label_singular() ),
					'desc'		=> '<p class="description">'.sprintf( esc_html__('Endpoint for the %s -> Edit page, Default is: edit-collection.','woocl'), woo_cl_get_label_singular() ).'</p>',
					'type'		=> 'text',
					'class'		=> '',
				    'std' 		=> 'edit-collection',
					'default' 	=> 'edit-collection',
				),
				array(
					'id'		=> 'cl_collection_author_text',
					'name'		=> sprintf( esc_html__( '%s Author', 'woocl' ), woo_cl_get_label_singular() ),
					'desc'		=> '<p class="description">'.sprintf( esc_html__('Endpoint for the %s -> Author page, Default is: collection-author.','woocl'), woo_cl_get_label_singular() ).'</p>',
					'type'		=> 'text',
					'class'		=> '',
				    'std' 		=> 'collection-author',
					'default' 	=> 'collection-author',
				),
				// End Misc Option section
				array( 
					'type' 		=> 'sectionend',
					'id' 		=> 'cl_endpoints_settings'
				),
			));

		} else if( 'cl_license' == $current_section ) { // IF license tab selected

			$button_title = ($this->activation_status) ? 'Deactivate License' : 'Activate License' ;
			$activationcode = '';
			if( $this->activation_status ) {
				$code_length = strlen( $this->activation_code ) / 2;
				$activationcode = substr( $this->activation_code, 0, $code_length ) . str_repeat( '*', $code_length );
				$description = '';
			}else{
				$description = esc_html__( 'WooCommerce Collections was not able to automatically validate your license.', 'woocl' );
				
			}

			$settings = apply_filters( 'woo_cl_license', array(

				// Start License Settings section
				array( 
					'name'	=>	esc_html__( 'License', 'woocl' ) ,
					'type'	=>	'title',
					'desc'	=>	$description,
					'id'	=>	'cl_license'
				),
				array(
					'title'         => esc_html__( 'License Key', 'woocl' ),
					'id'            => 'cl_license_key',
					'default'       => '',
					'desc_tip'      => esc_html__( 'Enter plugin license key', 'woocl' ),
					'type'          => 'text',
					'value'			=> $activationcode 
				),
				array(
					'title'         => esc_html__( 'Email Address', 'woocl' ),
					'id'            => 'cl_email_address',
					'default'       => '',
					'desc_tip'      => esc_html__( 'Enter email address', 'woocl' ),
					'type'          => 'email',
					'value'			=> $this->email_address 
				),

				array(
					'id'		=> 'woo_cl_license_button',
					'name'		=> 'Active Deactive License',
					'type'		=> 'woo_cl_license_button',
					'class'		=> 'button',
					'btn_title' => esc_html__( $button_title , 'woocl' ),
				),
				array(
					'id'		=> 'woo_cl_license_description',
					'name'		=> 'License Description',
					'type'		=> 'woo_cl_license_description',
					'class'		=> 'description',
				),
				array( 
					'type' => 'sectionend', 
					'id' => 'cl_license' 
				),
				
			));

		} else { // Else go for general settings

			$settings = apply_filters( 'woo_cl_after_collection_settings', array(

				array(
						'title' => esc_html__( 'General Settings', 'woocommerce' ),
						'type' 	=> 'title',
						'id' 	=> 'cl_general_settings'
					),
				
	            array(
	                'name' 		=> sprintf( esc_html__('%s Page', 'woocl'), woo_cl_get_label_plural() ),
	                'desc' 		=> sprintf( esc_html__('%sSelect the page where users will view their %s. This page should include the %s shortcode.%s', 'woocl'), '<p class="description">', woo_cl_get_label_plural(), '<code>[woo_cl_collections]</code>', '</p>' ),
	                'id' 		=> 'cl_coll_lists_page',
	                'type' 		=> 'single_select_page',
	                'class' 	=> 'chosen_select_nostd',
	                'desc_tip' 	=> '',
	            ),
				array(
					'id'		=> 'cl_guest_options',
					'name'		=> sprintf( esc_html__( 'Enable %s for Guest Users', 'woocl' ), woo_cl_get_label_singular() ) ,
					'desc'		=> '',
					'type'		=> 'checkbox',
					'desc_tip'	=> sprintf( esc_html__( 'Check this box if you want to allow Guest users to create their own %s.','woocl' ), woo_cl_get_label_plural() )
				),
				array(
					'id'		=> 'cl_disable_user_role',
					'name' 		=> esc_html__('Exclude User Roles', 'woocl'),
					'desc' 		=> sprintf( esc_html__( '%sSelect the user roles that you want to restrict from adding items to %s.%s', 'woocl' ), '<p class="description">', woo_cl_get_label_singular(true), '</p>' ),
	                'default' 	=> '',
	                'std' 		=> '',
	                'type' 		=> 'woo_cl_multiselect',
	                'val'		=> $user_editable_role
				),
				array(
					'id'		=> 'cl_max_collections_per_user',
					'name'		=> sprintf( esc_html__( 'Maximum %s Per User', 'woocl' ), woo_cl_get_label_plural() ),
					'desc'		=> sprintf( esc_html__( '%sEnter the maximum number of %s allowed per user. Leave it empty for unlimited.%s', 'woocl' ), '<p class="description">', woo_cl_get_label_plural(true), '</p>' ),
					'type'		=> 'text',
					'class'		=> 'small-text',
					'desc_tip'	=> ''
				),
				array(
					'id'		=> 'cl_max_products_per_collection',
					'name'		=> sprintf( esc_html__( 'Maximum Products Per %s', 'woocl' ), woo_cl_get_label_singular() ),
					'desc'		=> sprintf( esc_html__( '%sEnter the maximum number of products allowed per %s. Leave it empty for unlimited.%s', 'woocl' ), '<p class="description">', woo_cl_get_label_singular(true), '</p>' ),
					'type'		=> 'text',
					'class'		=> 'small-text',
					'desc_tip'	=> ''
				),
				array(
					'id'		=> 'cl_enable_coll_add_all_to_cart',
					'name'		=> esc_html__( 'Enable Bulk Add To Cart', 'woocl' ),
					'desc'		=> '',
					'type'		=> 'checkbox',
					'desc_tip'	=> esc_html__( 'Check this box if you wanted to allow users to add multiple products to cart by single click.','woocl' )
				),
				array(
					'id'		=> 'cl_front_coll_privacy',
					'name'		=> sprintf( esc_html__( '%s Privacy', 'woocl' ), woo_cl_get_label_singular() ) ,
					'desc'		=> '',
					'default'   => 'yes',
					'type'		=> 'checkbox',
					'desc_tip'	=> sprintf( esc_html__( 'Check this box if you want to allow user to manage %s\'s privacy option on front end.','woocl' ), woo_cl_get_label_plural() )
				),
				array(
					'id'		=> 'cl_new_coll_privacy',
					'name'		=> sprintf( esc_html__( 'Default %s Privacy', 'woocl' ), woo_cl_get_label_singular() ),
					'desc'		=> sprintf( esc_html__('%sSelect the default privacy for the %s.%s', 'woocl'), '<p class="description">', woo_cl_get_label_plural(), '</p>' ),
					'type'		=> 'select',
					'class'		=> 'chosen_select_nostd',
				    'std' 		=> 'public',
					'default' 	=> 'public',
					'options' 	=> array(  'public' => esc_html__( 'Public', 'woocl' ), 'private' => esc_html__( 'Private', 'woocl' ) )	
				),
		       ));

				$settings_2 = array(
					
					array(
						'type' 	=> 'sectionend',
						'id' 	=> 'cl_social_options'
					),
			        array(
							'title' => esc_html__( 'Social Settings', 'woocommerce' ),
							'type' 	=> 'title',
							'id' 	=> 'cl_social_settings'
						),
					array(
		                'name' 			=> esc_html__('Social Options', 'woocl'),
		                'desc' 			=> esc_html__('Facebook', 'woocl'),
						'id' 			=> 'cl_sharing_facebook',
		                'default' 		=> '',
		                'std' 			=> '',
		                'type' 			=> 'checkbox',
				            'checkboxgroup' => 'start'
			            ),
		            array(
		                'desc' 			=> esc_html__('Twitter', 'woocl'),
		                'id' 			=> 'cl_sharing_twitter',
		                'default' 		=> '',
		                'std' 			=> '',
		                'type' 			=> 'checkbox',
		                'checkboxgroup' => ''
		            ),
				/*	array(
		                'desc' 			=> esc_html__('Google', 'woocl'),
		                'id' 			=> 'cl_sharing_google',
						'default' 		=> '',
		                'std' 			=> '',
		                'type' 			=> 'checkbox',
		                'checkboxgroup' => ''
		            ),*/
					array(
		                'desc' 			=> esc_html__('LinkedIn', 'woocl'),
		                'id' 			=> 'cl_sharing_linkedin',
						'default' 		=> '',
		                'std' 			=> '',
		                'type' 			=> 'checkbox',
		                'checkboxgroup' => ''
		            ),
					array(
		                'desc' 			=> esc_html__('Share Via Email', 'woocl'),
		                'id' 			=> 'cl_sharing_email',
						'default' 		=> '',
		                'std' 			=> '',
		                'type' 			=> 'checkbox',
		                'checkboxgroup' => 'end'
		            ),
					array(
						'type' 	=> 'sectionend',
						'id' 	=> 'cl_general_settings'
					),
				);

			//Merge all settings
		    $settings = apply_filters( 'woo_cl_general_settings', array_merge( $settings, $settings_2 ) );
	    }

		return apply_filters( 'woocommerce_get_settings_' . $this->id, $settings, $current_section );
	}
}

endif;

return new Woo_Cl_Settings_Tabs();
