<?php
// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Admin Class
 *
 * Handles generic License functionality.
 *
 * @package WPWeb WooCommerce Collections
 * @since 1.0.0
 */

class Woo_Cl_License {

	/**
	 * Handles to add plugin settings in Woocommerce -> Settings
	 *
	 * @package WPWeb WooCommerce Collections
	 * @since 1.1.5
	 */
	public function woo_cl_collection_admin_settings_tab_license( $settings ) {

		// Add settings in array.
		$settings[] = require_once WOO_CL_ADMIN . '/class-woo-cl-admin-settings-tabs.php';

		return $settings; // Return.
	}


	/**
	 * Handles the license activation & deactivation action
	 *
	 * @package WPWeb WooCommerce Collections
	 * @since 1.1.5
	 */
	public function woo_cl_activate_license() {

		$license_key    = sanitize_text_field( $_POST['license_key'] );
		$email          = sanitize_email( $_POST['email'] );
		$license_action = sanitize_text_field( $_POST['license_action'] );

		if ( $license_action == 'Activate License' ) {
			$data = $this->woo_cl_activation_settings( $license_key, $email, $license_action );
			if ( isset( $data['status'] ) && true == $data['status'] ) {
				update_option( 'woo_cl_activation_code', $license_key, false );
				update_option( 'woo_cl_email_address', $email, false );
				$final_activation_code = base64_encode( $license_key . '%' . $email );
				update_option( 'woo_cl_activated', $final_activation_code, false );
			}
			wp_send_json( $data );
		}

		if ( $license_action == 'Deactivate License' ) {
			$license_key = get_option( 'woo_cl_activation_code' );
			$data        = $this->woo_cl_activation_settings( $license_key, $email, $license_action );
			if ( true == $data['status'] ) {
				delete_option( 'woo_cl_activated' );
				delete_option( 'woo_cl_activation_code' );
				delete_option( 'woo_cl_email_address' );
			}
			wp_send_json( $data );
		}
		exit;
	}

	/**
	 * Handles the license activation & deactivation api call
	 *
	 * @package WPWeb WooCommerce Collections
	 * @since 1.1.5
	 */
	public function woo_cl_activation_settings( $license_key, $email, $license_action ) {

		$activation_code = $license_key;
		$email_address   = $email;
		$url             = WOO_CL_LICENSE_VALIDATOR;
		$curl            = curl_init();
		$fields          = array(
			'email'           => $email_address,
			'site_url'        => get_site_url(),
			'activation_code' => $activation_code,
			'activation'      => $license_action,
			'item_id'         => 12642527,
		);

		$fields_string = http_build_query( $fields );
		curl_setopt( $curl, CURLOPT_URL, $url );
		curl_setopt( $curl, CURLOPT_RETURNTRANSFER, true );
		curl_setopt( $curl, CURLOPT_HEADER, false );
		curl_setopt( $curl, CURLOPT_POST, true );
		curl_setopt( $curl, CURLOPT_POSTFIELDS, $fields_string );
		$data = json_decode( curl_exec( $curl ), true );
		return( $data );
	}

	/**
	 * Handle to display licence activation notice
	 *
	 * @package WPWeb WooCommerce Collections
	 * @since 1.1.5
	 */
	public function woo_cl_show_license_notice() {

		if ( ! woo_cl_is_license_activated() ) {
			if ( function_exists( 'get_current_screen' ) ) {
				// get the current screen.
				$screen          = get_current_screen();
				$is_license_page = false;
				if ( $screen->id == 'woocommerce_page_wc-settings' ) {
					if ( ( isset( $_GET['tab'] ) && $_GET['tab'] != 'woo-cl-settings' ) || ! isset( $_GET['tab'] ) ) {
						$is_license_page = true;
					} else {
						$is_license_page = false;
					}
				} else {
					$is_license_page = true;
				}

				if ( $is_license_page ) { ?>
					<div class="notice notice-error is-dismissible">
						<p>
						<?php
						$license_page_url = add_query_arg(
							array(
								'page' => 'wc-settings',
								'tab'  => 'woo-cl-settings',
							),
							admin_url( 'admin.php' )
						);
						printf( esc_html__( '%1$sWooCommerce Collections%2$s: Please %3$sactivate%4$s your license in order to use the plugin.', 'woocl' ), '<b>', '</b>', '<a href="' . $license_page_url . '">', '</a>' );
						?>
						</p>
					</div>
					<?php
				}
			}
		}
	}

	/**
	 * Handle licence script & style
	 *
	 * @package WPWeb WooCommerce Collections
	 * @since 1.1.5
	 */
	public function woo_cl_enqueue_license_script( $hook ) {

		if ( 'woocommerce_page_wc-settings' === $hook ) {

			$license_status = woo_cl_is_license_activated();
			if ( ( isset( $_GET['section'] ) && $_GET['section'] == 'cl_license' ) || ! ( $license_status ) ) {
				$is_cl_license = 'cl_license';
			} else {
				$is_cl_license = '';
			}
			wp_register_script( 'woo-cl-license-script', WOO_CL_URL . 'includes/js/woo-cl-license.js', array(), WOO_CL_LIB_VER, true );
			wp_localize_script(
				'woo-cl-license-script',
				'WooclLicense',
				array(
					'ajaxurl'          => admin_url( 'admin-ajax.php' ),
					'woo_cl_activated' => ( $license_status ) ? 'Deactivate License' : 'Activate License',
					'is_cl_license'    => $is_cl_license,
					'is_cl_activated'  => ( $license_status ) ? true : false,
				)
			);
			wp_enqueue_script( 'woo-cl-license-script' );

			wp_enqueue_script( 'sweetalert-script', WOO_CL_URL . 'includes/js/sweetalert2.all.min.js', array( 'jquery' ), WOO_CL_LIB_VER );

			wp_register_style( 'woo-cl-license-style', WOO_CL_URL . 'includes/css/woo-cl-license.css', array(), WOO_CL_LIB_VER );
				wp_enqueue_style( 'woo-cl-license-style' );
		}

	}


	/**
	 * Adding Hooks
	 *
	 * Adding proper hooks for the admin post list.
	 *
	 * @package WPWeb WooCommerce Collections
	 * @since 1.0.0
	 */
	public function add_hooks() {

		if ( ! woo_cl_is_license_activated() ) {
			// Add filter for adding plugin settings.
			add_filter( 'woocommerce_get_settings_pages', array( $this, 'woo_cl_collection_admin_settings_tab_license' ) );
		}

		// Action to activate & deactivate license.
		add_action( 'wp_ajax_woo_cl_activate_license', array( $this, 'woo_cl_activate_license' ) );
		add_action( 'admin_notices', array( $this, 'woo_cl_show_license_notice' ) );

		add_action( 'admin_enqueue_scripts', array( $this, 'woo_cl_enqueue_license_script' ) );

	}
}
