<?php
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Follow My blog post plugin compatibility Class
 * 
 * 
 * @package WPWeb WooCommerce Collections
 * @since 1.1.5
 */
class Woo_Cl_FMBP {

	public function woo_cl_after_setting_sections( $sections ) {

		// Add follow email template options
		$sections['cl_follow_email_options'] = esc_html__( 'Follow Settings', 'woocl' );

		return $sections;
	}
	/**
	 * Settings for Follow My Blog Post
	 * 
	 * @package WPWeb WooCommerce Collections
	 * @since 1.1.5
	 */
	public function woo_cl_register_fmbp_settings( $settings, $current_section ){
		
		if( 'cl_follow_email_options' == $current_section ) {

			$settings = apply_filters( 'woo_cl_follow_email_options', array(

				// Start Follow Settings section
				array( 
					'name'	=>	esc_html__( 'Follow Settings', 'woocl' ),
					'type'	=>	'title',
					'desc'	=>	'',
					'id'	=>	'cl_follow_setting'
				),
				array(
					'id'		=> 'cl_enable_follow_coll_author',
					'name'		=> esc_html__( 'Enable Follow Author Button', 'woocl' ),
					'desc'		=> '',
					'type'		=> 'checkbox',
					'desc_tip'	=> sprintf( esc_html__( 'Check this box if you want to enable follow %s\'s author.','woocl' ), woo_cl_get_label_singular() )
				),
				// End follow Option section
				array( 
					'type' 		=> 'sectionend',
					'id' 		=> 'cl_follow_setting'
				),
				// Start email Settings section
				array( 
					'name'	=>	esc_html__( 'Email Settings', 'woocl' ),
					'type'	=>	'title',
					'desc'	=>	'',
					'id'	=>	'cl_email_setting'
				),
				array(
					'id'		=> 'cl_email_subject',
					'name'		=> esc_html__( 'Email Subject', 'woocl' ),
					'desc'		=> '<p class="description">'.sprintf( esc_html__( 'This is the subject of the email that will be sent to the followers of the %1$s when new product added for that %1$s. Available template tags for subject fields are :','woocl' ), woo_cl_get_label_singular() ).
									'<br /><code>{collection_name}</code> - '.sprintf( esc_html__( 'displays the %s name', 'woocl' ), woo_cl_get_label_singular() ).
									'<br /><code>{collection_item_name}</code> - '.sprintf( esc_html__( 'displays the %s item name', 'woocl' ), woo_cl_get_label_singular() ).'</p>',
					'type'		=> 'text',
					'class'		=> 'regular-text'
				),
				array(
					'id'		=> 'cl_email_body',
					'name'		=> esc_html__( 'Email Body', 'woocl' ),
					'desc'		=> '<p class="description">'.sprintf( esc_html__( 'This is the body, main content of the email that will be sent to the followers of the %1$s when new product added for that %1$s. The available tags are:','woocl' ), woo_cl_get_label_singular() ).
									'<br /><code>{collection_name}</code> - '.sprintf( esc_html__('displays the %s name', 'woocl' ), woo_cl_get_label_singular() ).
									'<br /><code>{collection_item_name}</code> - '.sprintf( esc_html__('displays the %s item name', 'woocl' ), woo_cl_get_label_singular() ).
									'<br /><code>{collection_item_description}</code> - '.sprintf( esc_html__('displays the %s item description', 'woocl' ), woo_cl_get_label_singular() ).'</p>',
					'type'		=> 'woo_cl_textarea',
					'class'		=> 'large-text',
					'css' 		=> 'height: 200px;',
					'editor'	=> true
				),
				// End email Option section
				array( 
					'type' 		=> 'sectionend',
					'id' 		=> 'cl_email_setting'
				),
			));
		}

	   	return $settings;
	}

	public function woo_cl_manage_fmbp_custom_columns( $column_name, $post_id ){

		global $wpdb, $post, $current_user;

		//get prefix
		$prefix		= WOO_CL_META_PREFIX;
		
		//get user ID
		$user_ID	= isset( $current_user->ID ) ? $current_user->ID : '';

		switch( $column_name ) {
			case 'follower':
									$follow_count	= 0;
									
										
									// get followers counts
									$follow_count 	= wpw_fp_get_post_followers_count( $post->ID );
									
									echo $follow_count;
									echo '<div id="inline_' . $post->ID . '_coll_follower" class="hidden">' . $follow_count . '</div>';
									break;
		}
	}

	public function woo_cl_add_new_fmbp_collections_columns( $new_columns ){
		unset( $new_columns['author'] );
 		unset( $new_columns['title'] );
 		unset( $new_columns['date'] );
 		unset( $new_columns['products'] );
 		unset( $new_columns['total'] );
 		unset( $new_columns['featured'] );
 		

 		$new_columns['title'] 		= esc_html__( 'Title', 'woocl' );
		$new_columns['products'] 	= esc_html__( 'Products', 'woocl' );
		$new_columns['featured'] 	= esc_html__( 'Featured?', 'woocl' );
		
		$new_columns['follower'] = esc_html__( 'Followers', 'woocl' );
		
		$new_columns['author'] 		= esc_html__( 'Author', 'woocl' );
 		$new_columns['total'] 		= esc_html__( 'Total', 'woocl' );
 		$new_columns['date'] 		= esc_html__( 'Date', 'woocl' );

 		return $new_columns;
	}

	/**
	 * Hide update notification checkbox
	 * 
	 * Handle to hide update notification checkbox
	 * 
	 * @package WPWeb WooCommerce Collections
 	 * @since 1.0.0
	 */
	public function woo_cl_follow_notification_checkbox_display( $is_display ) {
		
		global $post;
		
		$coll_post_type	= WOO_CL_POST_TYPE_COLL;
		
		if( isset( $post->post_type ) && $post->post_type == $coll_post_type ) {
			
			$is_display	= false;
		}
		
		return $is_display;
	}

	/**
	 * Remove Follow Metabox
	 * 
	 * Handle to remove follow metabox in collection post type
	 * 
	 * @package WPWeb WooCommerce Collections
 	 * @since 1.0.0
	 */
	public function woo_cl_remove_followm_metabox() {
		
		$post_type	= WOO_CL_POST_TYPE_COLL;
		
		//Remove follow post type from collection post type page
		remove_meta_box( 'wpw_fp_follow_me_metabox' , $post_type , 'normal' );
	}


	/**
	 * Insert Collection Item Notification
	 * 
	 * @package WPWeb WooCommerce Collections
	 * @since 1.0.0
	 */
	public function wpw_fp_insert_collection_item( $coll_productid, $collection_id , $collection_item_name, $collection_item_id ) {
		
			
		global $wpw_fp_model, $woo_cl_model;
		
		$prefix 	= WOO_CL_META_PREFIX;
		
		//Get Collection name
		$collection_name	= get_the_title( $collection_id );
		
		//Update collection product id
		$product_id		= get_post_meta( $collection_item_id, $prefix.'coll_product_id', true );
		
		//Get collection data
		$coll_item_data	= get_post( $collection_item_id );
		
		//Get Collection Content
		$collection_item_description	= $woo_cl_model->woo_cl_get_limit_char( $coll_item_data->post_content );
		
		$cl_fp_shortcodes	= array( "{collection_name}", "{collection_item_name}", "{collection_item_description}" );
		$cl_fp_replacecodes	= array( $collection_name, $collection_item_name, $collection_item_description );
		
		$subject	= get_option( 'cl_email_subject' );
		$subject	= str_replace( $cl_fp_shortcodes, $cl_fp_replacecodes, $subject );
		
		$message	= get_option( 'cl_email_body' );
		$message	= str_replace( $cl_fp_shortcodes, $cl_fp_replacecodes, nl2br( $message ) );
		
		//For Notify collection followers
		$flag		= $wpw_fp_model->wpw_fp_post_send_mail( $subject, $message, $collection_id,'post', '' );

		//For Notify author's followers
		$coll_author= get_post_field( 'post_author', $collection_id );
		$flag		= $wpw_fp_model->wpw_fp_author_send_mail( $coll_author, $subject, $message, $collection_id, 'post' );
	}
	
	/**
	 * Display Follow message on Collection page
	 * 
	 * @package WPWeb WooCommerce Collections
	 * @since 1.0.0
	 */
	public function woo_cl_follow_message_collection_id( $post_id = '' ) {

		//Get collection view page end point
		$woo_cl_view_slug	= get_option( 'cl_view_collection_text' );
		$woo_cl_view_slug	= trim( $woo_cl_view_slug ) != '' ? $woo_cl_view_slug : 'view-collection';
		
		if( woo_cl_is_page( $woo_cl_view_slug ) ) {
			
			//Get collection ID
			$collection_id	= get_query_var( $woo_cl_view_slug );
			
			//Assign collection id to post ID
			$post_id		= $collection_id;
		}
		
		return $post_id;
	}

	/**
	 * Get Collection Subscribed URL
	 * 
	 * @package WPWeb WooCommerce Collections
	 * @since 1.0.0
	 */
	public function woo_cl_subscribed_collection_url( $redirect_url = '', $colloection_id = '' ) {
		global $woo_cl_model;

		if( woo_cl_is_collection( $colloection_id ) ) {
			
			$redirect_url	= $woo_cl_model->woo_cl_get_collection_item_page_url( $colloection_id );
		}
		
		return $redirect_url;
	}


	/**
	 * Send follow my blog post
	 * email using woocommerce template
	 * 
	 * @package WPWeb WooCommerce Collections
	 * @since 1.0.0
	 */
	public function woo_cl_send_email_externaly( $externally_send_email, $email, $subject, $headers, $message ) {
				
		// load the mailer class
		$mailer        = WC()->mailer();	
		$emails = new WC_Email(); // create a new email to send mail using woocommerce
		
		// get site name and set it to heading
		$site_name = get_bloginfo( 'name' ); 	
		$attachments = '';
		
		// get unsubscibe message
		$unsubscibe_message = wpw_fp_get_unsubscribe_message();
		if( !empty( $unsubscibe_message ) )
			$message .= $unsubscibe_message;
	
		ob_start();
		
		// get header template
		wc_get_template( 'emails/email-header.php', array( 'email_heading' => $site_name ) );
		
		// actual message
		echo $message;
		
		// get footer template
		wc_get_template( 'emails/email-footer.php' );
		
		$message = ob_get_clean();
		
		// send email
		$externally_send_email['success'] = $emails->send( $email, $subject, $message, $headers, $attachments );
		
		$externally_send_email['send_mail_externally'] = true;
		
		return $externally_send_email;
	}

	/**
	 * Adding Hooks
	 * 
	 * Adding proper hooks for the WCMP compability.
	 * 
	 * @package WPWeb WooCommerce Collections
 	* @since 1.1.5
	 */
	public function add_hooks() {

		add_filter('woo_cl_setting_sections', array( $this, 'woo_cl_after_setting_sections'));

		add_filter('woocommerce_get_settings_woo-cl-settings', array( $this, 'woo_cl_register_fmbp_settings'),10, 2 );

		add_action('manage_'.WOO_CL_POST_TYPE_COLL.'_posts_custom_column', array($this,'woo_cl_manage_fmbp_custom_columns'), 10, 2);

		add_filter('manage_edit-'.WOO_CL_POST_TYPE_COLL.'_columns', array($this,'woo_cl_add_new_fmbp_collections_columns'));

		//Hide follow my blog post  metaboxes from collections post type
		add_filter( 'wpw_fp_check_post_update_notification', array($this, 'woo_cl_follow_notification_checkbox_display' ) );
		add_action( 'do_meta_boxes', array( $this, 'woo_cl_remove_followm_metabox' ) );


		//message send when collection item has been added from follo my blog post plugin
		add_action( 'woo_cl_add_to_collection_success_popup', array( $this, 'wpw_fp_insert_collection_item' ), 10, 4 );

		//Display message on collection page
		add_filter( 'wpw_fp_follow_display_message_post_id', array( $this, 'woo_cl_follow_message_collection_id' ) );
		add_filter( 'wpw_fp_subscribed_post_url', array( $this, 'woo_cl_subscribed_collection_url' ), 10, 2 );

		// add filter to send email using woocommece template
		add_filter( 'wpw_fp_send_email_externaly', array( $this, 'woo_cl_send_email_externaly' ), 10, 5 );
	}
}