<?php
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Ultimate member plugin compatibility Class
 * 
 * 
 * @package WPWeb WooCommerce Collections
 * @since 1.1.5
 */
class Woo_Cl_Ultimate_Members {

	/**
	 * Settings for Ultimate Member
	 * 
	 * @package WPWeb WooCommerce Collections
	 * @since 1.1.5
	 */
	public function woo_cl_register_um_settings( $settings ){
		
		//Check if Ultimate Member plugin active
		$um_settings = array(
					array(
		                'desc' 			=> sprintf( esc_html__( 'Check this box to display My %s on Ultimate Member Account page.', 'woocl' ), woo_cl_get_label_plural() ),
						'id' 			=> 'cl_enable_um_account_page',
		                'std' 			=> '',
		                'default' 		=> '',
		                'type' 			=> 'checkbox',
				        'checkboxgroup' => ''
			        ),
	            );

	    $settings = array_merge( $settings, $um_settings );

		return $settings;
	}

	/**
	 * Register style for Ultimate Member account page
	 * 
	 * @package WPWeb WooCommerce Collections
	 * @since 1.1.5
	 */
	public function woo_cl_um_public_style(){
		global $woo_cl_scripts;

		if( get_option( 'cl_enable_um_account_page' ) == 'yes' && um_is_core_page('account') ){

			$woo_cl_scripts->woo_cl_wp_register_style( 'woo-cl-collection-listing', '', array(), WOO_CL_LIB_VER );
			wp_enqueue_style( 'woo-cl-collection-listing' ); // Enqueue Collection Listing style

			$woo_cl_scripts->woo_cl_wp_register_style( 'woo-cl-item-listing', '', array(), WOO_CL_LIB_VER );
			wp_enqueue_style( 'woo-cl-item-listing' ); // Enqueue Item listing style

			$woo_cl_scripts->woo_cl_wp_register_style( 'woo-cl-collection-edit', '', array(), WOO_CL_LIB_VER );
			wp_enqueue_style( 'woo-cl-collection-edit' ); // Enqueue collection edit style

			$woo_cl_scripts->woo_cl_wp_register_style( 'woo-cl-email-share', '', array(), WOO_CL_LIB_VER );
			wp_enqueue_style( 'woo-cl-email-share' ); // Enqueue email share style
		}
	}


	/**
	 * Register script for Ultimate Member account page
	 * 
	 * @package WPWeb WooCommerce Collections
	 * @since 1.1.5
	 */
	public function woo_cl_um_public_scripts(){
		

		if( get_option( 'cl_enable_um_account_page' ) == 'yes' && um_is_core_page('account') ) {
			//Get all Messages
			$messages	= woo_cl_messages();

			wp_register_script( 'woo-cl-ajax-listing', WOO_CL_URL. 'includes/js/woo-cl-ajax-listing.js', array('jquery' ), WOO_CL_LIB_VER, true );
			wp_enqueue_script( 'woo-cl-ajax-listing' ); //enqueue ajax listing script
			wp_register_script( 'woo-cl-public-script', WOO_CL_URL. 'includes/js/woo-cl-public.js', array('jquery' ), WOO_CL_LIB_VER, true );
			
			//localize script to pass some variable to javascript file from php file
			//pass ajax url to access wordpress ajax file at front side for public
			wp_localize_script( 'woo-cl-public-script','Woo_cl_Public_Ajax',array(
																				'ajaxurl' 			=> admin_url( 'admin-ajax.php', ( is_ssl() ? 'https' : 'http' ) ),
																				'no_more_coll' 		=> isset( $messages['no_more_coll'] ) 		? $messages['no_more_coll'] 		: '',
																				'no_more_coll_item'	=> isset( $messages['no_more_coll_item'] ) 	? $messages['no_more_coll_item']	: '',
																				'select_all_chk'	=> esc_html__("Select All", "woocl"),
																				'unselect_all_chk'	=> esc_html__("Unselect All", "woocl"),
																				'add_bulk_products_to_cart_error'	=> esc_html__("Something worng, No item added to cart.", "woocl"),
																			));
			wp_enqueue_script( 'woo-cl-public-script' ); //enqueue public script for item & edit item listing
		}
	}

	/**
	 * Add My Collections tab on Ultimate Member
	 * 
	 * @package WPWeb WooCommerce Collections
	 * @since 1.1.5
	 */
	public function woo_cl_um_mycollection_tab( $tabs ) {

		$tabs[800]['mycollection']['icon'] = 'um-icon-heart';
		$tabs[800]['mycollection']['title'] = sprintf( esc_html__( 'My %s', 'woocl' ), woo_cl_get_label_plural() );
		$tabs[800]['mycollection']['custom'] = true;
		return $tabs;
	}

	/**
	 * Link tab content My Collections tab on Ultimate Member
	 * 
	 * @package WPWeb WooCommerce Collections
	 * @since 1.1.5
	 */
	public function woo_cl_um_account_tab__mycollection( $info ) {
		global $ultimatemember;
		extract( $info );

		$output = $ultimatemember->account->get_tab_output( 'mycollection' );
		if ( $output ) { 
			echo $output; 
		}
	}

	/**
	 * Build Tab Content My Collections tab on Ultimate Member
	 * 
	 * @package WPWeb WooCommerce Collections
	 * @since 1.1.5
	 */
	public function woo_cl_um_account_content_hook_mycollection( $output ){

		ob_start(); ?>

		<div class="um-field">
			
		<?php
			$no_of_collections	=  woo_cl_get_no_of_collection_on_my_account_page();		

			$args = array(
				'post_status'	 	=> array( 'publish', 'private' ),							
				'posts_per_page' 	=> $no_of_collections,							
				'paged'	 		 	=> 1,							
				'collection_title'	=> sprintf( esc_html__( 'My %s', 'woocl' ), woo_cl_get_label_plural() ),							
				'enable_see_all'	=> 'true',							
				'show_count'		=> 'true',
				'fixed_coll'	 	=> true
			);
			woo_cl_my_collections( apply_filters( 'woo_cl_um_account_page_collection_args', $args ) );
		?>
		</div>		

		<?php
		$output .= ob_get_contents();
		ob_end_clean();

		return $output;
	}

	/**
	 * Adding Hooks
	 * 
	 * Adding proper hooks for the Ultimate members compability.
	 * 
	 * @package WPWeb WooCommerce Collections
 	* @since 1.1.5
	 */
	public function add_hooks() {

		add_filter('woo_cl_before_seaching_display_settings', array( $this, 'woo_cl_register_um_settings'));

		//style for public
		add_action( 'wp_enqueue_scripts', array( $this, 'woo_cl_um_public_style' ) );

		//script for popup
		add_action( 'wp_enqueue_scripts', array( $this, 'woo_cl_um_public_scripts' ) );

		if( get_option( 'cl_enable_um_account_page' ) == 'yes' ) {

			//Action to add My Collections on Ultimate Member page
		 	add_filter( 'um_account_page_default_tabs_hook', array( $this, 'woo_cl_um_mycollection_tab' ), 100 );
		 	add_action( 'um_account_tab__mycollection', array( $this, 'woo_cl_um_account_tab__mycollection' ) );
		 	add_filter( 'um_account_content_hook_mycollection', array( $this, 'woo_cl_um_account_content_hook_mycollection' ) );
		}
	}
}