<?php
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * WCMP plugin compatibility Class
 * 
 * 
 * @package WPWeb WooCommerce Collections
 * @since 1.1.5
 */
class Woo_Cl_WCMP {

	/**
	 * Settings for WCMP
	 * 
	 * @package WPWeb WooCommerce Collections
	 * @since 1.1.5
	 */
	public function woo_cl_register_wcmp_settings( $settings ){
		
		$wcmp_settings = array(
					array(
		                'desc' 			=> sprintf( esc_html__( 'Check this box to display My %s on WooCommerce Marketplace\'s vendor dashboard page.', 'woocl' ), woo_cl_get_label_plural() ),
						'id' 			=> 'cl_enable_wcmp_account_page',
		                'std' 			=> '',
		                'default' 		=> '',
		                'type' 			=> 'checkbox',
				        'checkboxgroup' => ''
			        ),
	            );

	    $settings = array_merge( $settings, $wcmp_settings );

	   	return $settings;
	}

	/**
	 * Add Collections tab to
	 * WCMp Vendor Dashboard page
	 * 
	 * @package WPWeb WooCommerce Collections
	 * @since 1.2.2
	 */
	public function woo_cl_wcmp_dashboard_tab_mycollections( $vendor_nav ){

		global $current_user, $woo_cl_model;

        //Get User ID
        $user_name  = isset( $current_user->user_login ) ? $current_user->user_login : '';

        if( !empty( $user_name ) ) {//If user is not empty

            $mycoll_url = $woo_cl_model->woo_cl_get_collection_page_url( $user_name );
			$vendor_nav['mycollection'] = array(
	            'label' => sprintf( esc_html__( 'My %s', 'woocl' ), woo_cl_get_label_plural() ),
	            'url' => $mycoll_url,
	            'capability' => apply_filters('wcmp_vendor_dashboard_menu_collection_capability', true),
	            'position' => 70,
	            'submenu' => array(),
	            'link_target' => '_blank',
	            'nav_icon' => 'wcmp-font ico-add-icon',
			);
		}

		return $vendor_nav;
	}
	

	/**
	 * Adding Hooks
	 * 
	 * Adding proper hooks for the WCMP compability.
	 * 
	 * @package WPWeb WooCommerce Collections
 	* @since 1.1.5
	 */
	public function add_hooks() {

		add_filter('woo_cl_before_seaching_display_settings', array( $this, 'woo_cl_register_wcmp_settings'));

		// Check if my collections on Dokan page enabled
		if( get_option( 'cl_enable_wcmp_account_page' ) == 'yes' ) {

			// Add filter to add collections on WooCommerce Marketplace dashboard
			add_filter( 'wcmp_vendor_dashboard_nav', array( $this, 'woo_cl_wcmp_dashboard_tab_mycollections' ) );
		}
	}
}